@@ -1,4 +1,3 @@
-import multiprocessing as mp
 import pwd
 import os
 from odoo_env.client import Client
@@ -44,27 +43,23 @@ class OdooEnv(object):
             ##############################################################
             # Clone repo if does not exist
             ##############################################################
-
             cmd = CloneRepo(
                 self,
-                usr_msg='cloning {}'.format(repo.formatted),
-                command='git -C {} {}'.format(self.client.sources_dir,
-                                              repo.clone),
-                args='{}{}'.format(self.client.sources_dir, repo.dir_name)
+                usr_msg='cloning %s' % repo.formatted,
+                command='git -C %s %s' % (self.client.sources_dir, repo.clone),
+                args='%s%s' % (self.client.sources_dir, repo.dir_name)
             )
             ret.append(cmd)
 
             ##############################################################
             # Update repo if exist
             ##############################################################
-
             cmd = PullRepo(
                 self,
-                usr_msg='pulling {}'.format(repo.formatted),
-                command='git -C {}{} {}'.format(self.client.sources_dir,
-                                                repo.dir_name,
-                                                repo.pull),
-                args='{}{}'.format(self.client.sources_dir, repo.dir_name)
+                usr_msg='pulling %s' % repo.formatted,
+                command='git -C %s%s %s' %(self.client.sources_dir, repo.dir_name,
+                                           repo.pull),
+                args='%s%s' % (self.client.sources_dir, repo.dir_name)
             )
             ret.append(cmd)
 
@@ -84,10 +79,9 @@ class OdooEnv(object):
                 if file_extension == '.zip':
                     filenames.append(filedesc)
 
-        if len(filenames) > 1:
+        if len(filenames) > 0:
             filenames.sort()
-            msg = 'List of available backups for client {} \n\n'.format(
-                client_name)
+            msg = 'List of available backups for client %s\n\n' % client_name
             for filedesc in filenames:
                 msg += filedesc + '\n'
         else:
@@ -101,11 +95,26 @@ class OdooEnv(object):
         ret.append(cmd)
         return ret
 
-    def restore(self, client_name, database=False, backup_file=False,
-                deactivate=False):
-        """ Restaurar un backup desde el directorio backup_dir
+    def make_scp_command(self, client_name, backup_file):
+        """ Crea el comando para bajar el archivo desde el server
         """
+        cli = Client(self, client_name)
+        if backup_file:
+            # Bajar el backup backup_file del server
+            cmd = 'scp %s:%s%s %sserver_bkp.zip' % (cli.prod_server, cli.backup_dir,
+                                                    backup_file, cli.backup_dir)
+        else:
+            # bajar el ultimo archivo del server
+            _file = 'ssh %s ls -t %s | head -1' % (cli.prod_server, cli.backup_dir)
+            cmd = 'scp %s:%s$(%s) %sserver_bkp.zip' % (cli.prod_server, cli.backup_dir,
+                                                       _file, cli.backup_dir)
+        return cmd
 
+    def restore(self, client_name, database=False, backup_file=False,
+                no_deactivate=False, from_server=False):
+        """ Restaurar un backup desde el directorio backup_dir o desde el server de
+            produccion
+        """
         self._client = Client(self, client_name)
         ret = []
 
@@ -115,20 +124,30 @@ class OdooEnv(object):
         else:
             msg += 'from newest backup '
 
-        if deactivate:
-            msg += 'and performing deactivation.'
+        if not no_deactivate and self._client.debug:
+            msg += 'and performing deactivation '
+
+        if from_server:
+            command = self.make_scp_command(client_name, backup_file)
+            cmd = Command(
+                self,
+                command=command,
+                usr_msg="Downloading server backup"
+            )
+            ret.append(cmd)
 
         command = 'sudo docker run --rm -i '
-        command += '--link pg-{}:db '.format(client_name)
-        command += '-v {}:/backup '.format(self.client.backup_dir)
-        command += '-v {}data_dir/filestore:/filestore '.format(
-            self.client.base_dir)
-        command += '--env NEW_DBNAME={} '.format(database)
-        if backup_file:
-            command += '--env ZIPFILE={} '.format(backup_file)
-        if deactivate:
+        command += '--link pg-%s:db ' % client_name
+        command += '-v %s:/backup ' % self.client.backup_dir
+        command += '-v %sdata_dir/filestore:/filestore ' % self.client.base_dir
+        command += '--env NEW_DBNAME=%s ' % database
+        if backup_file and not from_server:
+            command += '--env ZIPFILE=%s ' % backup_file
+        if from_server and self._client.debug:
+            command += '--env ZIPFILE=server_bkp.zip '
+        if not no_deactivate and self._client.debug:
             command += '--env DEACTIVATE=True '
-        command += 'jobiols/dbtools '
+        command += 'jobiols/dbtools:1.2.0 '
 
         cmd = Command(
             self,
@@ -161,8 +180,8 @@ class OdooEnv(object):
         for image in self._client._images:
             cmd = PullImage(
                 self,
-                command='sudo docker pull {}'.format(image.name),
-                usr_msg='Pulling Image {}'.format(image.short_name)
+                command='sudo docker pull %s' % image.name,
+                usr_msg='Pulling Image %s' % image.short_name
             )
             ret.append(cmd)
         return ret
@@ -204,8 +223,8 @@ class OdooEnv(object):
             r_dir = '%s%s' % (self.client.base_dir, w_dir)
             cmd = MakedirCommand(
                 self,
-                command='mkdir -p {}'.format(r_dir),
-                args='{}'.format(r_dir)
+                command='mkdir -p %s' % r_dir,
+                args='%s' % r_dir
             )
             ret.append(cmd)
 
@@ -215,11 +234,11 @@ class OdooEnv(object):
         if self.debug:
 
             for w_dir in self._get_packs():
-                r_dir = '{}{}'.format(self.client.version_dir, w_dir)
+                r_dir = '%s%s' % (self.client.version_dir, w_dir)
                 cmd = MakedirCommand(
                     self,
-                    command='mkdir -p {}'.format(r_dir),
-                    args='{}'.format(r_dir)
+                    command='mkdir -p %s' % r_dir,
+                    args='%s' % r_dir
                 )
                 ret.append(cmd)
 
@@ -229,10 +248,10 @@ class OdooEnv(object):
 
         if self.debug:
             for w_dir in self._get_packs():
-                r_dir = '{}{}'.format(self.client.version_dir, w_dir)
+                r_dir = '%s%s' % (self.client.version_dir, w_dir)
                 cmd = Command(
                     self,
-                    command='chmod og+w {}'.format(r_dir)
+                    command='chmod og+w %s' % r_dir
                 )
                 ret.append(cmd)
 
@@ -241,10 +260,10 @@ class OdooEnv(object):
         ##################################################################
 
         for w_dir in ['config', 'data_dir', 'log', 'backup_dir']:
-            r_dir = '{}{}'.format(self.client.base_dir, w_dir)
+            r_dir = '%s%s' % (self.client.base_dir, w_dir)
             cmd = Command(
                 self,
-                command='chmod o+w {}'.format(r_dir)
+                command='chmod o+w %s' % r_dir
             )
             ret.append(cmd)
 
@@ -254,11 +273,11 @@ class OdooEnv(object):
 
         if self.nginx:
             for w_dir in ['cert', 'conf', 'log']:
-                r_dir = '{}{}'.format(BASE_DIR, 'nginx/' + w_dir)
+                r_dir = '%s%s' % (BASE_DIR, 'nginx/' + w_dir)
                 cmd = MakedirCommand(
                     self,
-                    command='mkdir -p {}'.format(r_dir),
-                    args='{}'.format(r_dir)
+                    command='mkdir -p %s' % r_dir,
+                    args='%s' % r_dir
                 )
                 ret.append(cmd)
 
@@ -267,11 +286,11 @@ class OdooEnv(object):
         ##################################################################
 
         if self.nginx:
-            r_dir = '{}{}'.format(BASE_DIR, 'nginx/conf/')
+            r_dir = '%s%s' % (BASE_DIR, 'nginx/conf/')
             cmd = CreateNginxTemplate(
                 self,
-                command='{}nginx.conf'.format(r_dir),
-                args='{}nginx.conf'.format(r_dir),
+                command='%snginx.conf' % r_dir,
+                args='%snginx.conf' % r_dir,
                 usr_msg='Generating nginx.conf template',
                 client_name=client_name
             )
@@ -280,28 +299,26 @@ class OdooEnv(object):
         ##################################################################
         # Extracting sources from image if debug enabled
         ##################################################################
-        if self.debug:
+        if self.debug and self.extract_sources:
             for module in self._get_packs():
-                msg = 'Extracting {} from image {}.debug'.format(
-                    module, self.client.get_image('odoo').name)
-                command = 'sudo docker run -it --rm '
-                command += '--entrypoint=/extract_{}.sh '.format(module)
-                command += '-v {}{}/:/mnt/{} '.format(self.client.version_dir,
-                                                      module, module)
-                command += '{}.debug '.format(
+                msg = 'Extracting %s from image %s.debug' % (module,
                     self.client.get_image('odoo').name)
+                command = 'sudo docker run -it --rm '
+                command += '--entrypoint=/extract_%s.sh ' % module
+                command += '-v %s%s/:/mnt/%s ' % (self.client.version_dir, module, module)
+                command += '%s.debug ' % self.client.get_image('odoo').name
 
                 cmd = ExtractSourcesCommand(
                     self,
                     command=command,
-                    args='{}{}'.format(self.client.version_dir, module),
+                    args='%s%s' % (self.client.version_dir, module),
                     usr_msg=msg,
                 )
                 ret.append(cmd)
 
             # poner permisos de escritura
             for module in self._get_packs():
-                r_dir = '{}{}'.format(self.client.version_dir, module)
+                r_dir = '%s%s' % (self.client.version_dir, module)
                 cmd = Command(
                     self,
                     command='sudo chmod -R og+w %s/' % r_dir,
@@ -777,3 +794,7 @@ class OdooEnv(object):
     @property
     def nginx(self):
         return self._options['nginx']
+
+    @property
+    def extract_sources(self):
+        return self._options['extract_sources']
